#!/usr/bin/env python3

import json

letterforms = '''\
       |       |       |       |       |       |       | |
  ###  |  ###  |  ###  |   #   |       |  ###  |  ###  |!|
  #  # |  #  # |  #  # |       |       |       |       |"|
  # #  |  # #  |#######|  # #  |#######|  # #  |  # #  |#|
 ##### |#  #  #|#  #   | ##### |   #  #|#  #  #| ##### |$|
###   #|# #  # |### #  |   #   |  # ###| #  # #|#   ###|%|
  ##   | #  #  |  ##   | ###   |#   # #|#    # | ###  #|&|
  ###  |  ###  |   #   |  #    |       |       |       |'|
   ##  |  #    | #     | #     | #     |  #    |   ##  |(|
  ##   |    #  |     # |     # |     # |    #  |  ##   |)|
       | #   # |  # #  |#######|  # #  | #   # |       |*|
       |   #   |   #   | ##### |   #   |   #   |       |+|
       |       |       |  ###  |  ###  |   #   |  #    |,|
       |       |       | ##### |       |       |       |-|
       |       |       |       |  ###  |  ###  |  ###  |.|
      #|     # |    #  |   #   |  #    | #     |#      |/|
  ###  | #   # |#     #|#     #|#     #| #   # |  ###  |0|
   #   |  ##   | # #   |   #   |   #   |   #   | ##### |1|
 ##### |#     #|      #| ##### |#      |#      |#######|2|
 ##### |#     #|      #| ##### |      #|#     #| ##### |3|
#      |#    # |#    # |#    # |#######|     # |     # |4|
#######|#      |#      |###### |      #|#     #| ##### |5|
 ##### |#     #|#      |###### |#     #|#     #| ##### |6|
###### |#    # |    #  |   #   |  #    |  #    |  #    |7|
 ##### |#     #|#     #| ##### |#     #|#     #| ##### |8|
 ##### |#     #|#     #| ######|      #|#     #| ##### |9|
   #   |  ###  |   #   |       |   #   |  ###  |   #   |:|
  ###  |  ###  |       |  ###  |  ###  |   #   |  #    |;|
    #  |   #   |  #    | #     |  #    |   #   |    #  |<|
       |       |#######|       |#######|       |       |=|
  #    |   #   |    #  |     # |    #  |   #   |  #    |>|
 ##### |#     #|      #|   ### |   #   |       |   #   |?|
 ##### |#     #|# ### #|# ### #|# #### |#      | ##### |@|
   #   |  # #  | #   # |#     #|#######|#     #|#     #|A|
###### |#     #|#     #|###### |#     #|#     #|###### |B|
 ##### |#     #|#      |#      |#      |#     #| ##### |C|
###### |#     #|#     #|#     #|#     #|#     #|###### |D|
#######|#      |#      |#####  |#      |#      |#######|E|
#######|#      |#      |#####  |#      |#      |#      |F|
 ##### |#     #|#      |#  ####|#     #|#     #| ##### |G|
#     #|#     #|#     #|#######|#     #|#     #|#     #|H|
  ###  |   #   |   #   |   #   |   #   |   #   |  ###  |I|
      #|      #|      #|      #|#     #|#     #| ##### |J|
#    # |#   #  |#  #   |###    |#  #   |#   #  |#    # |K|
#      |#      |#      |#      |#      |#      |#######|L|
#     #|##   ##|# # # #|#  #  #|#     #|#     #|#     #|M|
#     #|##    #|# #   #|#  #  #|#   # #|#    ##|#     #|N|
#######|#     #|#     #|#     #|#     #|#     #|#######|O|
###### |#     #|#     #|###### |#      |#      |#      |P|
 ##### |#     #|#     #|#     #|#   # #|#    # | #### #|Q|
###### |#     #|#     #|###### |#   #  |#    # |#     #|R|
 ##### |#     #|#      | ##### |      #|#     #| ##### |S|
#######|   #   |   #   |   #   |   #   |   #   |   #   |T|
#     #|#     #|#     #|#     #|#     #|#     #| ##### |U|
#     #|#     #|#     #|#     #| #   # |  # #  |   #   |V|
#     #|#  #  #|#  #  #|#  #  #|#  #  #|#  #  #| ## ## |W|
#     #| #   # |  # #  |   #   |  # #  | #   # |#     #|#|
#     #| #   # |  # #  |   #   |   #   |   #   |   #   |Y|
#######|     # |    #  |   #   |  #    | #     |#######|Z|
 ##### | #     | #     | #     | #     | #     | ##### |[|
#      | #     |  #    |   #   |    #  |     # |      #|\|
 ##### |     # |     # |     # |     # |     # | ##### |]|
   #   |  # #  | #   # |       |       |       |       |^|
       |       |       |       |       |       |#######|_|
       |  ###  |  ###  |   #   |    #  |       |       |`|
       |   ##  |  #  # | #    #| ######| #    #| #    #|a|
       | ##### | #    #| ##### | #    #| #    #| ##### |b|
       |  #### | #    #| #     | #     | #    #|  #### |c|
       | ##### | #    #| #    #| #    #| #    #| ##### |d|
       | ######| #     | ##### | #     | #     | ######|e|
       | ######| #     | ##### | #     | #     | #     |f|
       |  #### | #    #| #     | #  ###| #    #|  #### |g|
       | #    #| #    #| ######| #    #| #    #| #    #|h|
       |    #  |    #  |    #  |    #  |    #  |    #  |i|
       |      #|      #|      #|      #| #    #|  #### |j|
       | #    #| #   # | ####  | #  #  | #   # | #    #|k|
       | #     | #     | #     | #     | #     | ######|l|
       | #    #| ##  ##| # ## #| #    #| #    #| #    #|m|
       | #    #| ##   #| # #  #| #  # #| #   ##| #    #|n|
       |  #### | #    #| #    #| #    #| #    #|  #### |o|
       | ##### | #    #| #    #| ##### | #     | #     |p|
       |  #### | #    #| #    #| #  # #| #   # |  ### #|q|
       | ##### | #    #| #    #| ##### | #   # | #    #|r|
       |  #### | #     |  #### |      #| #    #|  #### |s|
       |  #####|    #  |    #  |    #  |    #  |    #  |t|
       | #    #| #    #| #    #| #    #| #    #|  #### |u|
       | #    #| #    #| #    #| #    #|  #  # |   ##  |v|
       | #    #| #    #| #    #| # ## #| ##  ##| #    #|w|
       | #    #|  #  # |   ##  |   ##  |  #  # | #    #|#|
       |  #   #|   # # |    #  |    #  |    #  |    #  |y|
       | ######|     # |    #  |   #   |  #    | ######|z|
  ###  | #     | #     |##     | #     | #     |  ###  |{|
   #   |   #   |   #   |       |   #   |   #   |   #   |||
  ###  |     # |     # |     ##|     # |     # |  ###  |}|
 ##    |#  #  #|    ## |       |       |       |       |~|
'''.splitlines()

table = {}
for form in letterforms:
    if '|' in form:
        table[form[-2]] = form[:-3].split('|')
ROWS = len(list(table.values())[0])

def banner22(word):
    texto = ""
    for row in range(ROWS):
        for c in word:
            texto += table[c][row]
        texto += "\n"
    return texto


##──── The figlet font clr5x6.flf converted to a dict ────────────────────────────────────────────────────────────────────────────
letters_clr5x6 = { 
    " ":['     ','     ','     ','     ','     ','     '], "!":['  #  ','  #  ','  #  ','     ','  #  ','     '], '"':[' # # ',' # # ','     ','     ','     ','     '],
    "#":[' # # ','#####',' # # ','#####',' # # ','     '], "$":[' ### ','# #  ',' ### ','  # #',' ### ','     '], "%":['##  #','## # ','  #  ',' # ##','#  ##','     '],
    "&":['  ## ',' #   ','  # #',' # # ','  # #','     '], "´":['  #  ',' #   ','     ','     ','     ','     '], "(":['    #','   # ','  ## ','   # ','    #','     '],
    ")":[' #   ','  #  ','  #  ','  #  ',' #   ','     '], "*":[' #  #','  ## ',' ####','  ## ',' #  #','     '], "+":['  #  ','  #  ','#####','  #  ','  #  ','     '],
    ",":['     ','     ','     ','  #  ','  #  ',' #   '], "-":['     ','     ',' ####','     ','     ','     '], ".":['     ','     ','     ','  #  ','  #  ','     '],
    "/":['    #','   # ','  #  ',' #   ','#    ','     '], "0":['  ## ',' # ##',' ## #',' #  #','  ## ','     '], "1":['  #  ',' ##  ','  #  ','  #  ','  #  ','     '],
    "2":[' ### ','    #','  ## ',' #   ',' ####','     '], "3":[' ### ','    #','  ## ','    #',' ### ','     '], "4":['    #','   ##','  # #',' ####','    #','     '],
    "5":[' ####',' #   ',' ### ','    #',' ### ','     '], "6":['  ## ',' #   ',' ### ',' #  #','  ## ','     '], "7":[' ####','    #','   # ','  #  ',' #   ','     '],
    "8":['  ## ',' #  #','  ## ',' #  #','  ## ','     '], "9":['  ## ',' #  #','  ###','    #','  ## ','     '], ":":['  #  ','  #  ','     ','  #  ','  #  ','     '],
    ";":['  #  ','  #  ','     ','  #  ','  #  ',' #   '], "<":['   # ','  #  ',' #   ','  #  ','   # ','     '], "=":['     ',' ####','     ',' ####','     ','     '],
    ">":['  #  ','   # ','    #','   # ','  #  ','     '], "?":[' ### ','    #','  ## ','     ','  #  ','     '], "@":['  ## ',' # ##',' # ##',' #   ','  ## ','     '],
    "A":['  ## ',' #  #',' #  #',' ####',' #  #','     '], "B":[' ### ',' #  #',' ### ',' #  #',' ### ','     '], "C":['  ###',' #   ',' #   ',' #   ','  ###','     '],
    "D":[' ### ',' #  #',' #  #',' #  #',' ### ','     '], "E":[' ####',' #   ',' ### ',' #   ',' ####','     '], "F":[' ####',' #   ',' ### ',' #   ',' #   ','     '],
    "G":['  ###',' #   ',' # ##',' #  #','  ###','     '], "H":[' #  #',' #  #',' ####',' #  #',' #  #','     '], "I":[' ### ','  #  ','  #  ','  #  ',' ### ','     '],
    "J":['   ##','    #','    #',' #  #','  ## ','     '], "K":[' #  #',' # # ',' ##  ',' # # ',' #  #','     '], "L":[' #   ',' #   ',' #   ',' #   ',' ####','     '],
    "M":[' #  #',' ####',' ####',' #  #',' #  #','     '], "N":[' #  #',' ## #',' # ##',' #  #',' #  #','     '], "O":['  ## ',' #  #',' #  #',' #  #','  ## ','     '],
    "P":[' ### ',' #  #',' ### ',' #   ',' #   ','     '], "Q":['  ## ',' #  #',' #  #',' #  #','  ## ','   ##'], "R":[' ### ',' #  #',' ### ',' # # ',' #  #','     '],
    "S":['  ###',' #   ','  ## ','    #',' ### ','     '], "T":['#####','  #  ','  #  ','  #  ','  #  ','     '], "U":[' #  #',' #  #',' #  #',' #  #','  ## ','     '],
    "V":[' #  #',' #  #',' #  #','  ## ','  ## ','     '], "W":[' #  #',' #  #',' ####',' ####',' #  #','     '], "X":[' #  #',' #  #','  ## ',' #  #',' #  #','     '],
    "Y":['#   #',' # # ','  #  ','  #  ','  #  ','     '], "Z":[' ####','   # ','  #  ',' #   ',' ####','     '], "[":['   ##','   # ','   # ','   # ','   ##','     '],
    "\\":['#    ',' #   ','  #  ','   # ','    #','     '], "]":[' ##  ','  #  ','  #  ','  #  ',' ##  ','     '], "^":['  #  ',' # # ','     ','     ','     ','     '],
    "_":['     ','     ','     ','     ','     ',' ####'], "`":['   # ','    #','     ','     ','     ','     '], "a":['     ','  ###',' #  #',' # ##','  # #','     '],
    "b":[' #   ',' ### ',' #  #',' #  #',' ### ','     '], "c":['     ','  ###',' #   ',' #   ','  ###','     '], "d":['    #','  ###',' #  #',' #  #','  ###','     '],
    "e":['     ','  ## ',' ####',' #   ','  ## ','     '], "f":['   ##','  #  ',' ### ','  #  ','  #  ','     '], "g":['     ','  ###',' #  #','  ###','    #','  ## '],
    "h":[' #   ',' ### ',' #  #',' #  #',' #  #','     '], "i":['  #  ','     ','  #  ','  #  ','  #  ','     '], "j":['    #','     ','    #','    #',' #  #','  ## '],
    "k":[' #   ',' # ##',' ##  ',' # # ',' #  #','     '], "l":[' ##  ','  #  ','  #  ','  #  ',' ### ','     '], "m":['     ',' #  #',' ####',' #  #',' #  #','     '],
    "n":['     ',' # # ',' ## #',' #  #',' #  #','     '], "o":['     ','  ## ',' #  #',' #  #','  ## ','     '], "p":['     ',' ### ',' #  #',' #  #',' ### ',' #   '],
    "q":['     ','  ###',' #  #',' #  #','  ###','    #'], "r":['     ',' # ##',' ##  ',' #   ',' #   ','     '], "s":['     ','  ###',' ##  ','   ##',' ### ','     '],
    "t":['  #  ',' ####','  #  ','  #  ','   ##','     '], "u":['     ',' #  #',' #  #',' # ##','  # #','     '], "v":['     ',' #  #',' #  #','  ## ','  ## ','     '],
    "w":['     ',' #  #',' #  #',' ####',' #  #','     '], "x":['     ',' #  #','  ## ','  ## ',' #  #','     '], "y":['     ',' #  #',' #  #','  ###','    #','  ## '],
    "z":['     ',' ####','   # ','  #  ',' ####','     '], "|":['  #  ','  #  ','  #  ','  #  ','  #  ','     '], "}":[' #   ','  #  ','  ## ','  #  ',' #   ','     '],
    "~":[' #   ','# # #','   # ','     ','     ','     ']
}

##──── The figlet font clr6x6.flf converted to a dict ────────────────────────────────────────────────────────────────────────────
letters_clr6x6 = {
    " ":['      ','      ','      ','      ','      ','      '],"!":['   #  ','   #  ','   #  ','      ','   #  ','      '],'"':['  # # ','  # # ','      ','      ','      ','      '],
    "#":['  # # ',' #####','  # # ',' #####','  # # ','      '],"$":['  ### ',' # #  ','  ### ','   # #','  ### ','      '],"%":[' ##  #',' ## # ','   #  ','  # ##',' #  ##','      '],
    "&":['  ##  ',' #    ','  ## #',' #  # ','  ## #','      '],"´":['   #  ','  #   ','      ','      ','      ','      '],"(":['    # ','   #  ','  ##  ','   #  ','    # ','      '],
    ")":['  #   ','   #  ','   #  ','   #  ','  #   ','      '],"*":['   #  ',' # # #','  ### ',' # # #','   #  ','      '],"+":['   #  ','   #  ',' #####','   #  ','   #  ','      '],
    ",":['      ','      ','      ','   #  ','   #  ','  #   '],"-":['      ','      ',' #####','      ','      ','      '],".":['      ','      ','      ','   #  ','   #  ','      '],
    "/":['     #','    # ','   #  ','  #   ',' #    ','      '],"0":['  ### ',' #  ##',' # # #',' ##  #','  ### ','      '],"1":['   #  ','  ##  ','   #  ','   #  ','   #  ','      '],
    "2":[' #### ','     #','  ### ',' #    ',' #####','      '],"3":[' #### ','     #','  ### ','     #',' #### ','      '],"4":['    ##','   # #','  #  #',' #####','     #','      '],
    "5":[' #####',' #    ',' #### ','     #',' #### ','      '],"6":['  ### ',' #    ',' #### ',' #   #','  ### ','      '],"7":[' #####','     #','    # ','   #  ','  #   ','      '],
    "8":['  ### ',' #   #','  ### ',' #   #','  ### ','      '],"9":['  ### ',' #   #','  ####','     #','  ### ','      '],":":['   #  ','   #  ','      ','   #  ','   #  ','      '],
    ";":['   #  ','   #  ','      ','   #  ','   #  ','  #   '],"<":['    ##','  ##  ','##    ','  ##  ','    ##','      '],"=":['      ',' #####','      ',' #####','      ','      '],
    ">":['##    ','  ##  ','    ##','  ##  ','##    ','      '],"?":[' ###  ','    # ','  ##  ','      ','  #   ','      '],"@":['  ##  ',' # ## ',' # ## ',' #    ','  ##  ','      '],
    "A":['   #  ','  # # ',' #   #',' #####',' #   #','      '],"B":[' #### ',' #   #',' #### ',' #   #',' #### ','      '],"C":['  ### ',' #   #',' #    ',' #   #','  ### ','      '],
    "D":[' #### ',' #   #',' #   #',' #   #',' #### ','      '],"E":[' #####',' #    ',' #### ',' #    ',' #####','      '],"F":[' #####',' #    ',' #### ',' #    ',' #    ','      '],
    "G":['  ####',' #    ',' #  ##',' #   #','  ####','      '],"H":[' #   #',' #   #',' #####',' #   #',' #   #','      '],"I":['  ### ','   #  ','   #  ','   #  ','  ### ','      '],
    "J":['   ###','     #','     #',' #   #','  ### ','      '],"K":[' #  # ',' # #  ',' ##   ',' # #  ',' #  # ','      '],"L":[' #    ',' #    ',' #    ',' #    ',' #####','      '],
    "M":[' #   #',' ## ##',' # # #',' # # #',' #   #','      '],"N":[' #   #',' ##  #',' # # #',' #  ##',' #   #','      '],"O":['  ### ',' #   #',' #   #',' #   #','  ### ','      '],
    "P":[' #### ',' #   #',' #### ',' #    ',' #    ','      '],"Q":['  ### ',' #   #',' #   #',' #   #','  ### ','    ##'],"R":[' #### ',' #   #',' #### ',' # #  ',' #  ##','      '],
    "S":['  ####',' #    ','  ### ','     #',' #### ','      '],"T":[' #####','   #  ','   #  ','   #  ','   #  ','      '],"U":[' #   #',' #   #',' #   #',' #   #','  ### ','      '],
    "V":[' #   #',' #   #','  # # ','  # # ','   #  ','      '],"W":[' #   #',' # # #',' # # #',' ## ##',' #   #','      '],"X":[' #   #','  # # ','   #  ','  # # ',' #   #','      '],
    "Y":[' #   #','  # # ','   #  ','   #  ','   #  ','      '],"Z":[' #####','    # ','   #  ','  #   ',' #####','      '],"[":['   ###','   #  ','   #  ','   #  ','   ###','      '],
    "\\":[' #    ','  #   ','   #  ','    # ','     #','      '],"]":[' ###  ','   #  ','   #  ','   #  ',' ###  ','      '],"^":['   #  ','  # # ',' #   #','      ','      ','      '],
    "_":['      ','      ','      ','      ','      ',' #####'],"`":['   #  ','    # ','      ','      ','      ','      '],"a":['      ','  ####',' #   #',' #  ##','  ## #','      '],
    "b":[' #    ',' #### ',' #   #',' #   #',' #### ','      '],"c":['      ','  ### ',' #    ',' #    ','  ### ','      '],"d":['     #','  ####',' #   #',' #   #','  ####','      '],
    "e":['      ','  ### ',' #####',' #    ','  ### ','      '],"f":['   ###','  #   ',' #### ','  #   ','  #   ','      '],"g":['      ','  ####',' #   #','  ####','     #','  ### '],
    "h":[' #    ',' #### ',' #   #',' #   #',' #   #','      '],"i":['   #  ','      ','   #  ','   #  ','   #  ','      '],"j":['    # ','      ','    # ','    # ',' #  # ','  ##  '],
    "k":[' #    ',' # ## ',' ##   ',' # #  ',' #  # ','      '],"l":['  ##  ','   #  ','   #  ','   #  ','  ### ','      '],"m":['      ',' ## # ',' # # #',' # # #',' #   #','      '],
    "n":['      ',' # ## ',' ##  #',' #   #',' #   #','      '],"o":['      ','  ### ',' #   #',' #   #','  ### ','      '],"p":['      ',' #### ',' #   #',' #   #',' #### ',' #    '],
    "q":['      ','  ####',' #   #',' #   #','  ####','     #'],"r":['      ',' # ## ',' ##   ',' #    ',' #    ','      '],"s":['      ','  ####',' ###  ','   ###',' #### ','      '],
    "t":['  #   ',' #### ','  #   ','  #   ','   ## ','      '],"u":['      ',' #   #',' #   #',' #  ##','  ## #','      '],"v":['      ',' #   #','  # # ','  # # ','   #  ','      '],
    "w":['      ',' #   #',' # # #',' # # #','  # # ','      '],"x":['      ',' #  # ','  ##  ','  ##  ',' #  # ','      '],"y":['      ',' #   #',' #   #','  ####','     #','  ### '],
    "z":['      ',' #### ','   #  ','  #   ',' #### ','      '],"|":['   #  ','   #  ','   #  ','   #  ','   #  ','      '],"}":['  #   ','   #  ','   ## ','   #  ','  #   ','      '],
    "~":['  #   ',' # # #','    # ','      ','      ','      ']
}

class banner5x6:
    def get_banner(word,spacing:int=1):
        """Returns the banner as text without print it"""
        text = ""
        for row in range(6):
            for c in word:
                text += letters_clr5x6.get(c,' ')[row] + (" " * spacing)
            text += "\n"
        return text.rstrip()
    def print(word,spacing:int=1):
        """Prints the given text using the clr5x6 font"""
        print(banner5x6.get_banner(word))
    
class banner6x6():
    def get_banner(word,spacing:int=1):
        """Returns the banner as text without print it"""
        text = ""
        for row in range(6):
            for c in word:
                text += letters_clr6x6.get(c,' ')[row] + (" " * spacing)
            text += "\n"
        return text.rstrip()
    def print(word,spacing:int=1):
        """Prints the given text using the clr6x6 font"""
        print(banner6x6.get_banner(word,spacing))

if __name__ == "__main__":
    print("")
    banner5x6.print("FONT5x6")
    print("")
    banner6x6.print("FONT6x6")
    print("")
    banner6x6.print("FONT6x6 SPACING 0",spacing=0)
    print("")
    
    # with open('/usr/share/figlet/bdffonts/clr6x6.flf','r') as f:
    #     font = [line.strip() for line in f.readlines()]
    # counter = 0
    # char_list = []
    # char_dict = {}
    # lista = [' ','!','"','#','$','%','&','´','(',')','*','+',',','-','.','/','0','1','2','3','4','5','6','7','8','9',':',';','<','=','>','?','@',
    #          'A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z','[','\\',']','^','_','`',
    #          'a','b','c','d','e','f','g','h','i','j','k','l','m','n','o','p','q','r','s','t','u','v','w','x','y','z','(','|','}','~']
    # # print(len(lista))
    # for index,line in enumerate(font,0):
    #     try:
    #         if line.endswith(("$@","$@@")):
    #             new_line = line.replace("$@@","").replace("$@","").rjust(6," ")
    #             char_list.append(new_line)
    #         if line.endswith("$@@"):
    #             char_dict[lista[counter]] = char_list.copy()
    #             counter += 1
    #             char_list = []
    #     except:
    #         continue
    # # print(json.dumps(char_dict,indent=3,sort_keys=False,ensure_ascii=False))
    # for key,val in char_dict.items():
    # 	print(f'"{key}":{str(val).replace(", ",",")},')